{% extends base %} {% block head %}
{% end %} {% block body %}
{% set title = "代码模板" %} {% include "common/title/base_title.html" %}

转换方式

## 使用说明

类型 | 语法 | 示例 | 输出
--- | --- | --- | ---
POJO | `(name type)*` | `user_name Stringage int` |
    public String getUserName() {
      return this.userName;
    }
    public void setUserName(String userName) {
      this.userName = userName;
    }
toString | `(name)*` | `user_nameage` |
Java Converter | `source target (field)*` | `source target name age address` |

{% end %}